==> scraping-1.3.17-sources.jar: com/tenqube/visual_scraper/db/entity/OrderDetailWebRuleJson.java <==
package com.tenqube.visual_scraper.db.entity;

import android.arch.persistence.room.ColumnInfo;
import android.arch.persistence.room.Entity;
import android.arch.persistence.room.ForeignKey;
import android.arch.persistence.room.Index;
import android.arch.persistence.room.PrimaryKey;
import android.arch.persistence.room.TypeConverters;
import android.support.annotation.Nullable;

import com.tenqube.visual_scraper.db.converter.QueryRuleConverter;
import com.tenqube.visual_scraper.model.jsonParsing.QueryRuleBody;

import java.io.Serializable;

@Entity(tableName = "order_detail_web_rule",
        indices = {@Index(value = {"mall_id"}, unique = true)},
        foreignKeys =  {
                @ForeignKey(entity = MallEntity.class,
                        parentColumns = "m_id",
                        childColumns = "mall_id")})
@TypeConverters({QueryRuleConverter.class})
public class OrderDetailWebRuleJson implements Serializable {

    @PrimaryKey(autoGenerate = true)
    @ColumnInfo(name = "_id")
    private int id;

    @ColumnInfo(name = "mall_id")
    private final int mallId;

    @ColumnInfo(name = "url")
    private final QueryRuleBody url;

    @Nullable
    @ColumnInfo(name = "request_body")
    private final QueryRuleBody requestBody;


    public OrderDetailWebRuleJson(int mallId, QueryRuleBody url, @Nullable QueryRuleBody requestBody) {
        this.mallId = mallId;
        this.url = url;
        this.requestBody = requestBody;
    }

    public int getId() {
        return id;
    }

    public void setId(int id) {
        this.id = id;
    }

    public int getMallId() {
        return mallId;
    }

    public QueryRuleBody getUrl() {
        return url;
    }

    @Nullable
    public QueryRuleBody getRequestBody() {
        return requestBody;
    }


}

==> scraping-1.5.0-sources.jar: com/tenqube/visual_scraper/db/entity/OrderDetailWebRuleJson.java <==
package com.tenqube.visual_scraper.db.entity;

import android.arch.persistence.room.ColumnInfo;
import android.arch.persistence.room.Entity;
import android.arch.persistence.room.ForeignKey;
import android.arch.persistence.room.Index;
import android.arch.persistence.room.PrimaryKey;
import android.arch.persistence.room.TypeConverters;
import android.support.annotation.Nullable;

import com.tenqube.visual_scraper.db.converter.QueryRuleConverter;
import com.tenqube.visual_scraper.model.jsonParsing.QueryRuleBody;

import java.io.Serializable;

@Entity(tableName = "order_detail_web_rule",
        indices = {@Index(value = {"mall_id"}, unique = true)},
        foreignKeys =  {
                @ForeignKey(entity = MallEntity.class,
                        parentColumns = "m_id",
                        childColumns = "mall_id")})
@TypeConverters({QueryRuleConverter.class})
public class OrderDetailWebRuleJson implements Serializable {

    @PrimaryKey(autoGenerate = true)
    @ColumnInfo(name = "_id")
    private int id;

    @ColumnInfo(name = "mall_id")
    private final int mallId;

    @ColumnInfo(name = "url")
    private final QueryRuleBody url;

    @Nullable
    @ColumnInfo(name = "request_body")
    private final QueryRuleBody requestBody;

    @Nullable
    @ColumnInfo(name = "scripts")
    private final QueryRuleBody scripts;


    public OrderDetailWebRuleJson(int mallId, QueryRuleBody url, @Nullable QueryRuleBody requestBody, @Nullable QueryRuleBody scripts) {
        this.mallId = mallId;
        this.url = url;
        this.requestBody = requestBody;
        this.scripts = scripts;
    }

    public int getId() {
        return id;
    }

    public void setId(int id) {
        this.id = id;
    }

    public int getMallId() {
        return mallId;
    }

    public QueryRuleBody getUrl() {
        return url;
    }

    @Nullable
    public QueryRuleBody getScripts() {
        return scripts;
    }

    @Nullable
    public QueryRuleBody getRequestBody() {
        return requestBody;
    }


}
